@@ -13,5 +13,5 @@ def require(name):
 def exists(name):
     try:
         return require(name) is not None
-    except:
+    except Exception as e:  # noqa: F841
         return False
